<?php
/**
 * Custom template tags for Bloggo.
 *
 * @package Bloggo
 */

if ( ! function_exists( 'bloggo_posted_on' ) ) :
/**
 * Print HTML with meta information for the current post author, date and comments number.
 */
function bloggo_posted_on() {
	if ( 'post' === get_post_type() ) {
		printf( esc_html__( 'By %1$s on %2$s', 'bloggo' ),
			sprintf( '<a class="url fn n" href="%1$s">%2$s</a>',
				esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
				esc_html( get_the_author() )
			),
			bloggo_entry_date()
		);
	} elseif ( 'attachment' === get_post_type() ) {
		printf( esc_html__( 'On %s', 'bloggo' ),
			bloggo_entry_date()
		);
	}
	if ( comments_open() || get_comments_number() ) {
		echo '<span class="comments-link">';
		comments_popup_link( esc_html__( 'Leave a Comment', 'bloggo' ), esc_html__( '1 Comment', 'bloggo' ), esc_html__( '% Comments', 'bloggo' ) );
		echo '</span>';
	}
}
endif;

if ( ! function_exists( 'bloggo_posted_in' ) ) :
/**
 * Print HTML with meta information for the current post category and tag.
*/
function bloggo_posted_in() {
	if ( 'post' === get_post_type() ) {
		echo '<footer class="entry-footer"><div class="entry-meta">';
		$categories_list = get_the_category_list( ' ' );
		if ( $categories_list ) {
			printf( '<span class="cat-links">%1$s %2$s</span>',
				esc_html__( 'Posted in:', 'bloggo' ),
				$categories_list
			);
		}
		$tags_list = get_the_tag_list( '', ' ' );
		if ( $tags_list ) {
			printf( '<span class="tag-links">%1$s %2$s</span>',
				esc_html__( 'Tagged:', 'bloggo' ),
				$tags_list
			);
		}
		echo '</div></footer>';
	} elseif ( 'attachment' === get_post_type() ) {
		previous_post_link( '<footer class="entry-footer"><div class="entry-meta">' . esc_html__( 'Posted in: %link', 'bloggo' ) . '</div></footer>', '%title' );
	}
}
endif;

if ( ! function_exists( 'bloggo_entry_date' ) ) :
/**
 * Prints HTML with date information for the current post.
 */
function bloggo_entry_date() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}
	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( DATE_W3C ) ),
		get_the_date(),
		esc_attr( get_the_modified_date( DATE_W3C ) ),
		get_the_modified_date()
	);
	return $time_string;
}
endif;

if ( ! function_exists( 'bloggo_post_thumbnail' ) ) :
/**
 * Display an optional post thumbnail.
 */
function bloggo_post_thumbnail() {
	if ( post_password_required() || is_attachment() || ! has_post_thumbnail() )
		return;
	if ( is_singular() ) :
	?>
	<div class="post-thumbnail">
		<?php the_post_thumbnail(); ?>
	</div><!-- .post-thumbnail -->
	<?php else : ?>
	<a class="post-thumbnail" href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'post-thumbnail', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?></a>
	<?php endif;
}
endif;

if ( ! function_exists( 'bloggo_excerpt_more' ) ) :
/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ... and a 'Read More' link.
 */
function bloggo_excerpt_more( $more ) {
	if ( is_admin() ) {
		return $more;
	}
	$link = sprintf( '<span class="read-more"><a href="%1$s" class="more-link">%2$s</a></span>',
		esc_url( get_permalink( get_the_ID() ) ),
		esc_html__( 'Read More', 'bloggo' )
	);
	return ' &hellip; ' . $link;
}
add_filter( 'excerpt_more', 'bloggo_excerpt_more' );
endif;

if ( ! function_exists( 'bloggo_excerpt_length' ) ) :
/**
 * Change the excerpt length.
 */
function bloggo_excerpt_length( $length ) {
	if ( is_admin() ) {
		return $length;
	}
	return get_theme_mod( 'bloggo_excerpt_length', 55 );
}
add_filter( 'excerpt_length', 'bloggo_excerpt_length' );
endif;

/**
 * Wrap "Read more" link
 */
function bloggo_wrap_more_link( $more ) {
	if ( is_admin() ) {
		return $more;
	}
	return '<span class="read-more">' . $more . '</span>';
}
add_filter( 'the_content_more_link','bloggo_wrap_more_link' );

if ( ! function_exists( 'bloggo_loop_navigation' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 */
function bloggo_loop_navigation() {
	the_posts_pagination( array(
		'prev_text'          => '<span class="fa-chevron-left" aria-hidden="true"></span><span class="screen-reader-text">' . esc_html__( 'Previous', 'bloggo' ) . '</span>',
		'next_text'          => '<span class="screen-reader-text">' . esc_html__( 'Next', 'bloggo' ) . '</span><span class="fa-chevron-right" aria-hidden="true"></span>',
		'before_page_number' => '<span class="screen-reader-text">' . esc_html__( 'Page', 'bloggo' ) . ' </span>'
	) );
}
endif;
